/*
 * window_main.cpp
 * Copyright (C) Aitor Cuadrado Zubizarreta <aitor_czr@gnuinos.org>
 * 
 * gtk-ssh-askpass is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * gtk-ssh-askpass is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * See the COPYING file. * 
 */

#include "window_main.h"
#include "buttonbox.h"
#include <iostream>

// Translations:
#include <libintl.h>
#include <locale.h>

#define _(STRING) gettext(STRING)

WindowMain::WindowMain(char **argv)
:
  m_VBox(false, 5)
{
	/* Setting the i18n environment */
	setlocale (LC_ALL, "");
	
	/* Localization */
	textdomain("gtk-ssh-askpass");
	bindtextdomain("gtk-ssh-askpass", "/usr/share/locale");
	bind_textdomain_codeset ("gtk-ssh-askpass", "UTF-8");	  
	set_size_request( 350, 190 );
	
	//set_type_hint(Gdk::WINDOW_TYPE_HINT_SPLASHSCREEN) ;
  
	// set_title(_( "Password dialog" ));
	set_position( Gtk::WIN_POS_CENTER );
  
	m_Label.set_text(_("\nEnter the password:" )); 

	// As a GtkBin subclass a gtkmm__GtkDialog can only contain one widget at a time,
	// it already contains a widget of type Gtk::HBox:
	 
	//m_VBox = new Gtk::VBox();
	// In gtkmm3, it should be:
	// m_VBox = get_content_area();
	
	// This is only for Gtk::Dialog:
	//m_VBox=get_vbox();
 
	add( m_VBox );
	m_VBox.add( m_Label );
	m_VBox.add( m_Entry );
   
	m_Entry.set_visibility( false );  
	const std::string text= (_(" Show password "));
  
	bool mnemonic = false;	
	 
	m_CheckButton_Visible = new Gtk::CheckButton( text, mnemonic );  
	m_VBox.add( *m_CheckButton_Visible );
	m_CheckButton_Visible->set_can_focus(false);
	
	myButtonBox *pButtonBox = new myButtonBox(true, 15, Gtk::BUTTONBOX_END);
    m_VBox.pack_start(*pButtonBox, false, false, 5);
    
	m_Button_Close = Gtk::manage( new Gtk::Button(Gtk::Stock::CLOSE));
	pButtonBox->bbox->add( *m_Button_Close );
	
	m_Button_Execute = Gtk::manage( new Gtk::Button(Gtk::Stock::EXECUTE));
	pButtonBox->bbox->add( *m_Button_Execute );
 
	m_Entry.select_region(0, m_Entry.get_text_length());
	
	m_Button_Close->signal_clicked().connect
	(
		sigc::mem_fun(*this, &WindowMain::on_button_close)
	);   
	
	m_Button_Execute->signal_clicked().connect
	(
		sigc::bind<char**>
		(
			sigc::mem_fun(*this, &WindowMain::on_button_execute),
			argv
		)
	);  
	      
	m_CheckButton_Visible->signal_toggled().connect
	(
		sigc::mem_fun(*this, &WindowMain::on_checkbox_visibility_toggled)
	);
	
	m_Entry.grab_focus();	
	m_Entry.set_activates_default(true);
	m_Button_Execute->set_can_default();
	m_Button_Execute->grab_default();
	show_all_children();
	
}

// Destructor
WindowMain::~WindowMain()
{

}

void WindowMain::clear_entry_box()
{
	m_Entry.set_text("");
}

void WindowMain::on_checkbox_visibility_toggled()
{
	m_Entry.set_visibility( m_CheckButton_Visible->get_active() );
}

void WindowMain::on_button_close()
{
	hide();
}

void WindowMain::on_button_execute(char **argv)
{
	std::cout << m_Entry.get_text() << std::endl;
	hide();
}

